@@ -20,6 +20,7 @@ import numpy as np
 import matplotlib.pyplot as plt
 import statistics
 import seaborn as sns
+from shutil import which
 
 """
 How to use: Script is used through the create_circos_data() and make_diagram() methods.  See documentation pdf for more detail.
@@ -56,6 +57,28 @@ def create_circos_data(contigs, output_dir, project_title, hmm_db='', e_value=0.
     Returns:
         None
     """
+    # check if all required programs are in PATH
+    if which('circos') is None:
+        print("Could not find circos, please install and append to PATH")
+        sys.exit()
+
+    if which('prodigal') is None:
+        print("Could not find prodigal, please install and append to PATH")
+        sys.exit()
+
+    if blast_type == 'blastn':
+        if which('blastn') is None:
+            print("Could not find blastn, please install and append to PATH")
+            sys.exit()
+
+    if blast_type == 'tblastx':
+        if which('bl2seq') is None:
+            print("Could not find tblastx (called bl2seq in PATH), please install and append to PATH")
+            sys.exit()
+
+    if which('hmmscan') is None:
+        print("Could not find hmmscan, please install and append to PATH")
+        sys.exit()
 
     project_directory = output_dir + '/' + project_title
 
@@ -79,7 +102,7 @@ def create_circos_data(contigs, output_dir, project_title, hmm_db='', e_value=0.
     # links data
     links_df = links.get_link_data(list_of_correct_len_contigs_paths, blast_type, project_directory, min_blast_similarity_percentage, min_blast_similarity_length, link_transperacny, percent_link_overlap_tolerance, keep_blast_data)
     if links_df.empty:
-        print('No links were found.')
+        print('No links were found, your diagram will still be created but no links will be displayed between your sequences')
     links_df.to_csv(project_directory + '/circos_diagram_input_data/links.txt', sep=' ', index=False, header=False)
 
     # orf data
